=encoding utf8

=head1 NAME

Luo::Latn - Package for language Luo

=cut

package Locale::CLDR::Locales::Luo::Latn;

# This file auto generated
#	on Thu 29 Feb  5:43:51 pm GMT

use version;

our $VERSION = version->declare('v0.44.1');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Luo');

no Moo;

1;
